@@ -1,7 +1,7 @@
 package HTML::Make;
 use warnings;
 use strict;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 use Carp;
 use HTML::Valid::Tagset ':all';
 
@@ -16,7 +16,7 @@ our $blanktype = 'blank';
 
 # This is for checking %options for stray stuff.
 
-my %validoptions = (qw/text 1 nocheck 1 attr 1/);
+my %validoptions = (qw/text 1 nocheck 1 attr 1 class 1 id 1 href 1/);
 
 sub new
 {
@@ -54,6 +54,21 @@ sub new
 	if ($options{attr}) {
 	    $obj->add_attr (%{$options{attr}});
 	}
+	# Convenience shortcuts
+	if ($options{id}) {
+	    $obj->add_attr (id => $options{id});
+	}
+	if ($options{class}) {
+	    $obj->add_attr (class => $options{class});
+	}
+	if ($options{href}) {
+	    if ($type ne 'a') {
+		carp "href is only allowed with an 'a' element";
+	    }
+	    else {
+		$obj->add_attr (href => $options{href});
+	    }
+	}
 	for my $k (keys %options) {
 	    if (! $validoptions{$k}) {
 		carp "Unknown option '$k'";
@@ -131,6 +146,20 @@ sub check_mismatched_tags
     }
 }
 
+sub add_class
+{
+    my ($obj, $class) = @_;
+    my $oldclass = $obj->{attr}{class};
+    my $newclass;
+    if ($oldclass) {
+	$newclass = $oldclass . ' ' . $class;
+    }
+    else {
+	$newclass = $class;
+    }
+    $obj->{attr}{class} = $newclass;
+}
+
 sub HTML::Make::push
 {
     my ($obj, $el, %options) = @_;
